import java.util.ArrayList;

/**
 * DarkRoom: if you don't have the flashlight,
 * you can't do anything except exit via the exitdir.
 * Note that the flashlight can be lit *only* in the DarkRoom.
 * 
 * @author (Peter Dordal) 
 * @version (Spring 2006)
 */
public class DarkRoom extends Room
{
    // instance variables - replace the example below with your own
    private String exitdir;
//    private ArrayList inventory;

    /**
     * If you don't have a light, the only visible way out is exitdir
     */
    public DarkRoom(String exitdir, String desc)
    {
        super(desc);
        this.exitdir = exitdir;
        //inventory = inv;
    }

    /**
     * getShortDescription prints the dark description if there is no light.
     */
    public String getShortDescription(Player p) {
        ArrayList<Item> inventory = p.getInventory();
        if (Light.haslight(inventory)) 
            return super.getShortDescription(p);
        String desc = "in a pitch-dark place! You need a light!";
        return desc;
    }
    
    /**
     * getLongDescription doesn't print all the exits if it's dark, or the contents.
     */
    public String getLongDescription(Player p) {
        if (Light.haslight(p.getInventory()))
            return super.getLongDescription(p);
        String desc1 = getShortDescription(p);
        String desc2 = "The only way out you can see is a dimly lit exit to the " + exitdir;
        return desc1 + "\n" + desc2;
    }

    /**
     * respond: LIGHT FLASHLIGHT and TAKE <anything> (TAKE is disabled in the dark!)
     * Arguably LIGHT FLASHLIGHT should be moved to elsewhere.
     * Class demo: Respond to LIGHT <anything>, where we check if
     * <anything> is on the inventory and, if so, if it's a Light.
     */
    public void respond(Command c, Player p) {
        ArrayList<Item> inventory = p.getInventory();
        String commandWord = c.getCommandWord();
        String object = c.getSecondWord();
        if (commandWord.equals("light")) {
            if (object.equals("flashlight")) {
                Item f = Game.findByName("flashlight", inventory);
                if (f == null) {
                    System.out.println("you don't have the flashlight");
                    return;
                }
                if (f instanceof Light) { // It had better be!
                    Light fl = (Light) f;
                    fl.light();
                    System.out.println("The light is now on");
                    System.out.println(getLongDescription(p));
                } else {
                    System.out.println("Couldn't light the flashlight! Maybe it's broken!");
                }
            } else {
                System.out.println("You can't light that!");
            }
        } else if (commandWord.equals("take")) {
            if (Light.haslight(inventory)) { 
                super.respond(c, p);
            } else {
                System.out.println("It's too dark to see anything to take!");
            }
        } else {
            super.respond(c, p);
        }
    }
    
    /**
     * getExit: only allows going out the exitdir if we don't have the light.
     * Note that this is NOT necessarily the same as the way we came in!
     * What would it take to implement the latter?
     */
    public Room getExit(String direction, Player p) 
    {
        if (Light.haslight(p.getInventory()) || direction.equals(exitdir)) {
            return super.getExit(direction, p);
        } else {
            System.out.println("It's too dark to see any exit that way!");
            return null;
        }
    }
    
}
